@@ -1,4 +1,5 @@
 use bevy::prelude::Component;
+use bevy::reflect::GetTypeRegistration;
 use std::fmt::Debug;
 use std::hash::Hash;
 #[cfg(feature = "2D")]
@@ -19,13 +20,15 @@ mod neumann_3d_cell;
 
 /// Trait defining a Cell, every cell type (2d, 3d, hexagonal, etc) must implement this trait
 /// and define an associated `Coordinates` type
-pub trait Cell: Debug + Clone + Component {
+pub trait Cell: Debug + Clone + Component + GetTypeRegistration {
     /// Associated coordinates type
     type Coordinates: Clone + Debug + Default + Send + Sync + Eq + Hash;
 
     /// Retrieves the cell coordinates
+    #[must_use]
     fn coords(&self) -> &Self::Coordinates;
 
     /// Retrieves the coordinates of the neighbor cells
+    #[must_use]
     fn neighbor_coordinates(&self) -> Vec<Self::Coordinates>;
 }
