@@ -1,5 +1,5 @@
 use crate::components::Cell;
-use bevy::prelude::{Component, IVec3};
+use bevy::prelude::{Component, IVec3, Reflect};
 use std::ops::Deref;
 
 lazy_static::lazy_static! {
@@ -68,7 +68,7 @@ lazy_static::lazy_static! {
 /// [Moore] 3D cell, it has 26 neighbors and uses `IVec3` coordinates
 ///
 /// [Moore]: https://en.wikipedia.org/wiki/Moore_neighborhood
-#[derive(Debug, Clone, Component)]
+#[derive(Debug, Clone, Component, Reflect)]
 pub struct MooreCell3d {
     /// The 3D cell coordinates
     pub coords: IVec3,
@@ -99,6 +99,8 @@ impl Cell for MooreCell3d {
 
 impl MooreCell3d {
     /// Instantiates a new cell with `coords` values
+    #[must_use]
+    #[inline]
     pub const fn new(coords: IVec3) -> Self {
         Self { coords }
     }
