@@ -1,7 +1,7 @@
 use crate::CellState;
 use bevy::prelude::{Changed, Query, Sprite, Visibility};
 
-#[allow(clippy::type_complexity)]
+#[allow(clippy::needless_pass_by_value)]
 pub fn color_sprites<S>(mut query: Query<(&S, &mut Visibility, &mut Sprite), Changed<S>>)
 where
     S: CellState,
